@@ -22,7 +22,7 @@
  *
  * The table structure can be created by the scripts/sql/nag.sql script.
  *
- * $Horde: nag/lib/Driver/sql.php,v 1.60.2.15 2006/02/19 03:28:00 chuck Exp $
+ * $Horde: nag/lib/Driver/sql.php,v 1.60.2.18 2006/08/08 17:16:04 jan Exp $
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -182,7 +182,7 @@ class Nag_Driver_sql extends Nag_Driver {
                         (int)$alarm);
 
         /* Log the query at a DEBUG log level. */
-        Horde::logMessage(sprintf('Nag_Driver_sql::add(): %s', $query),
+        Horde::logMessage(sprintf('Nag_Driver_sql::_add(): %s', $query),
                           __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
         /* Attempt the insertion query. */
@@ -333,9 +333,12 @@ class Nag_Driver_sql extends Nag_Driver {
     /**
      * Retrieves tasks from the database.
      *
+     * @param integer $completed  Which tasks to retrieve (1 = all tasks,
+     *                            0 = incomplete tasks, 2 = complete tasks).
+     *
      * @return mixed  True on success, PEAR_Error on failure.
      */
-    function retrieve()
+    function retrieve($completed = 1)
     {
         /* Make sure we have a valid database connection. */
         $this->_connect();
@@ -344,6 +347,10 @@ class Nag_Driver_sql extends Nag_Driver {
         $query = sprintf('SELECT * FROM %s WHERE task_owner = ?',
                          $this->_params['table']);
         $values = array($this->_tasklist);
+        if ($completed != 1) {
+            $query .= ' AND task_completed = ?';
+            $values[] = $completed ? 1 : 0;
+        }
 
         /* Log the query at a DEBUG log level. */
         Horde::logMessage(sprintf('Nag_Driver_sql::retrieve(): %s', $query),
@@ -425,7 +432,7 @@ class Nag_Driver_sql extends Nag_Driver {
             /* Log the query at a DEBUG log level. */
             Horde::logMessage(sprintf('Nag_Driver_sql adding missing UID: %s', $query),
                               __FILE__, __LINE__, PEAR_LOG_DEBUG);
-            $this->_write_db->query($query, $values);
+            $this->_db->query($query, $values);
         }
 
         /* Create a new task based on $row's values. */
